@@ -16,8 +16,8 @@
  */
 package websocket.drawboard;
 
-import javax.servlet.ServletContextEvent;
-import javax.servlet.ServletContextListener;
+import jakarta.servlet.ServletContextEvent;
+import jakarta.servlet.ServletContextListener;
 
 public final class DrawboardContextListener implements ServletContextListener {
 
